﻿namespace msoui.Forms;
public partial class InstallForm: Form
{
    public InstallForm (List<string> fileList, string extractDir)
    {
        FileList = fileList;
        ExtractDir = extractDir;
        InitializeComponent();
    }

    public List<string> FileList { get; set; }

    public string ExtractDir { get; set; }

    private void LogIt(string message)
    {
        logList.Items.Add(message);
    }

    private void LogIt (string message, params object?[] args)
    {
        logList.Items.Add(string.Format(message, args));
    }

    public void StartProcess (string fileName)
    {
        process.StartInfo.FileName = fileName;
        process.StartInfo.Arguments = "/q /norestart";
        process.StartInfo.CreateNoWindow = false;
        process.EnableRaisingEvents = true;
        process.Exited += (_, _) => LogIt(@"[{0}] Процесс завершен с кодом {1}.", process.ExitTime, process.ExitCode);
        process.Start();
        process.WaitForExit();
    }


    public void InstallUpdates ()
    {
        LogIt("Начинаю установку...");

        int updatesCount = FileList.Count;

        LogIt("Выбрано {0} обновлений для установки...", updatesCount);

        int count = 0;

        foreach (string? file in FileList)
        {
            count++;

            decimal percentDone = Math.Round((decimal)count / updatesCount * 100);

            LogIt(@"Устанавливается файл {0} [{1} из {2}, {3}%]...", file, count, updatesCount, percentDone);
            StartProcess($"{ExtractDir}{file}");
            LogIt(@"Файл {0} установлен!", file);
        }

        MessageBox.Show(@"Набор обновлений успешно установлен!", @"Установка завершена", MessageBoxButtons.OK,
            MessageBoxIcon.Asterisk);

        DialogResult = DialogResult.OK;
    }

    private void startTimer_Tick (object sender, EventArgs e)
    {
        startTimer.Enabled = false;

        InstallUpdates();
    }

    private void InstallForm_Load (object sender, EventArgs e)
    {
        startTimer.Enabled = true;
    }
}
